;; -*- Coding: utf-8 -*-

;;General
(add-to-list 'load-path (expand-file-name "~/.elisp"))
(add-to-list 'load-path "/usr/local/share/emacs/site-lisp")
(add-to-list 'load-path "/usr/local/share/emacs/site-lisp/quail-gaelic")

;; fink -> pkgsrc
(add-to-list 'load-path "/sw/share/emacs/site-lisp")
(add-to-list 'load-path "/sw/share/emacs/site-lisp/elcleite")

;; Setting for encodings of the environment
(set-language-environment 'Japanese)
(set-default-coding-systems 'utf-8)
(set-terminal-coding-system 'utf-8)
(setq default-file-name-coding-system 'utf-8)
(set-keyboard-coding-system 'shift_jis-mac)
(quail-set-keyboard-layout "jp106")

(set-clipboard-coding-system 'utf-8)
;(set-clipboard-coding-system 'iso-2022-jp-mac)
;(set-clipboard-coding-system 'shift_jis-mac)

(setq truncate-partial-width-windows t)
(setq make-backup-files nil)

(setq read-file-name-completion-ignore-case t)
(tool-bar-mode nil)

(global-set-key "\C-\\" 'toggle-input-method)

(unless window-system
  (normal-erase-is-backspace-mode t))

;; browse-url
(setq browse-url-browser-function 'w3m-browse-url)
(global-set-key "\C-xm" 'browse-url-at-point)

(setq-default tab-width 4)
(global-font-lock-mode t)


;; font ------------------------------------------------------------------------
(if nil
    (progn (create-fontset-from-fontset-spec
	    (concat
	     "-*-sindarin-medium-r-normal-*-12-*-*-*-*-*-fontset-sindarin12,"
	     "ascii:-misc-Tengwar Sindarin-medium-r-normal-*-12-*-*-*-*-*-iso10646-1"))
	   (create-fontset-from-fontset-spec
	    (concat
	     "-*-sindarin-medium-r-normal-*-14-*-*-*-*-*-fontset-sindarin14,"
	     "ascii:-misc-Tengwar Sindarin-medium-r-normal-*-14-*-*-*-*-*-iso10646-1"))
	   (create-fontset-from-fontset-spec
	    (concat
	     "-*-sindarin-medium-r-normal-*-16-*-*-*-*-*-fontset-sindarin16,"
	     "ascii:-misc-Tengwar Sindarin-medium-r-normal-*-16-*-*-*-*-*-iso10646-1"))))


;; Setting for the Mode Line ---------------------------------------------------
(line-number-mode t)
(column-number-mode t)

(auto-compression-mode t)
(setq visible-bell t)
(setq ring-bell-function (lambda ()))
(windmove-default-keybindings)


;; Setting for Frames ----------------------------------------------------------
;(setq default-frame-alist (append default-frame-alist '((cursor-type . hbar)))


;; Setting for Packages --------------------------------------------------------

;; fucking-comma
;(require 'call-the-fucking-comma)

;; flyspell
(require 'flyspell)

;; mic-paren
(require 'mic-paren)
(paren-activate)

;; elscreen
(load "elscreen" "ElScreen" t)
(require 'elscreen-w3m)

;; cedet
(load-file "/usr/pkg/share/emacs/site-lisp/cedet/common/cedet.el")

;; ecb
(add-to-list 'load-path "/usr/pkg/share/emacs/site-lisp/ecb")
(require 'ecb-autoloads)

;; leim
(require 'gaelic)

;; bookmark
(setq bookmark-sort-flag nil)

;; sudoku
(autoload 'sudoku "sudoku" "The Sudoku" t)

;; mew
(autoload 'mew "mew" "Mew" t)

;; cleite
(autoload 'cleite "cleite" "Cleite RSS Aggregator -- Emacs Interface" t)

;; javascript
(autoload 'js2-mode "js2" nil t)
(add-to-list 'auto-mode-alist '("\\.js$" . js2-mode))

;; ido
(require 'ido)
(ido-mode t)

;; diary and todo
(add-hook 'diary-display-hook 'fancy-diary-display)
(add-hook 'list-diary-entries-hook 'include-other-diary-files)
(add-hook 'diary-hook 'appt-make-list)
;(add-hook 'mark-diary-entries-hook 'mark-included-diary-files)

(display-time)
(diary 0)

(global-set-key "\C-ct" 'todo-show)
(global-set-key "\C-ci" 'todo-insert-item)

;; sokoban
(autoload 'sokoban "sokoban.el" "Start a new game of Sokoban." t)
(autoload 'sokoban-mode "sokoban.el" "Play Sokoban in current buffer." t)
(setq sokoban-playerfiles-dir "/usr/local/var/games/emacs-sokoban")

;; nXML
(load "/usr/pkg/share/emacs/site-lisp/nxml-mode/rng-auto.el")
(defalias 'xml-mode 'nxml-mode)
(add-to-list 'auto-mode-alist '("\\.xml$" . nxml-mode))
(add-to-list 'auto-mode-alist '("\\.xi$" . nxml-mode))
(add-to-list 'auto-mode-alist '("\\.rdf$" . nxml-mode))
(add-to-list 'auto-mode-alist '("\\.rng$" . nxml-mode))

;; sstp
(autoload 'sstp-mode "sstp" "SSTP Editing Major-Mode" t)

;; scheme
(setq scheme-program-name "csi")

;; woman
(setq woman-manpath
      '("/usr/local/man"
	"/usr/local/share/man"
	"/usr/man"
	"/usr/share/man"
	"/sw/share/man"
	"/usr/local/teTeX/man"
	"/usr/X11R6/man"))
(setq woman-cache-filename "~/.wmncach.el")
(setq woman-imenu t)
(setq woman-use-own-frame nil)

;; ruby-mode
(autoload 'ruby-mode "ruby-mode" "Mode for editing ruby source files")
(setq auto-mode-alist
      (append '(("\\.rb$" . ruby-mode)) auto-mode-alist))
(setq interpreter-mode-alist (append '(("ruby" .ruby-mode))
                                     interpreter-mode-alist))
(autoload 'run-ruby "inf-ruby" "Run an inferior Ruby process")
(autoload 'inf-ruby-keys "inf-ruby" "set local key defs for inf-ruby in ruby-mode")
(add-hook 'ruby-mode-hook
          '(lambda ()
            (inf-ruby-keys)
          ))

;; Tramp
(setq tramp-default-method "ssh")

;; Haskell
(load (expand-file-name "~/sandbox/_haskell/haskell-mode/haskell-site-file"))
(add-hook 'haskell-mode-hook 'turn-on-haskell-doc-mode)
(add-hook 'haskell-mode-hook 'turn-on-haskell-indent)
;;(add-hook 'haskell-mode-hook 'turn-on-haskell-simple-indent)
;;(add-hook 'haskell-mode-hook 'turn-on-haskell-hugs)
(add-hook 'haskell-mode-hook 'turn-on-haskell-ghci)
(add-to-list 'auto-mode-alist '("\\.hsc$" . haskell-mode))

;; Hoogle
(autoload 'hoogle-lookup "hoogle" "Hoogle" t)
(global-set-key (kbd "C-c h") 'hoogle-lookup)

;; c
(mapcar (lambda (hook)
	  (add-hook hook
		    (lambda () (c-set-style "user"))))
	'(c-mode-hook
	  c++-mode-hook
	  objc-mode-hook
	  java-mode-hook))

;; librep
(setq auto-mode-alist
      (append
       '(("\\.jl$" . lisp-mode))
       auto-mode-alist))

;; css
(autoload 'css-mode "css-mode" "For editing CSS file" t)
(setq cssm-indent-level 4)
(setq cssm-mirror-mode nil)
(setq cssm-indent-function 'cssm-c-style-indenter)
(setq auto-mode-alist
      (append
       '(("\\.css$" . css-mode))
       auto-mode-alist))

;; EmacsWiki
(autoload 'emacs-wiki-find-file "emacs-wiki" "Emacs Wiki" t)
(defalias 'wiki 'emacs-wiki-find-file)

;; gnus
(setq gnus-select-method '(nntp "localhost" (nntp-port-number 1119)))

;; cperl
;; use cperl-mode instead of perl-mode
(defalias 'perl-mode 'cperl-mode)
;; configuration of indent
(setq cperl-invalid-face nil)
(setq cperl-indent-level 4)
(setq cperl-indent-parens-as-block t)
;(global-set-key "\C-c\C-p" 'cperl-mode)

;; Mule-UCS
;(unless (getenv "NO_MULE_UCS")
;  (require 'un-define))

;; SKK
;(require 'skk-autoloads) 
(global-set-key "\C-x\C-j" 'skk-mode)
(global-set-key "\C-xj" 'skk-auto-fill-mode)
(global-set-key "\C-xt" 'skk-tutorial)
;(setq skk-large-jisyo (expand-file-name "~/sandbox/_input-method/skk/dic/SKK-JISYO.L"))
;(setq skk-large-jisyo "/sw/share/ddskk/SKK-JISYO.L")
(setq skk-use-jisx0201-input-method t)
(setq skk-rom-kana-rule-list
      '(("@" nil "@")
	("wi" nil ("ヰ" . "ゐ"))
	("we" nil ("ヱ" . "ゑ"))
	;;("hh" "h" ("ン" . "ん"))
	;;("mm" "m" ("ン" . "ん"))
	("zx" nil ("ゝ" . "ヽ"))
	("zc" nil ("ゞ" . "ヾ"))))
(set-input-method 'japanese-skk) ; INPUT METHOD

;; navi2ch
(autoload 'navi2ch "navi2ch" "Navigator for 2ch for Emacs" t)

;; migemo
(load-library "migemo")

;; tiarra-conf
(setq load-path (cons (expand-file-name "~/sandbox/Tiarra") load-path))
(autoload 'tiarra-conf-mode "tiarra-conf" "tiarra.conf editing mode" t)

;; YaTeX
;(autoload 'yatex-mode "yatex" "Yet Another LaTeX mode" t)
;(setq YaTeX-kanji-code 3) ; euc-jp
;(setq tex-command "/usr/local/teTeX/bin/platex")
;(push "/usr/local/teTeX/bin" exec-path)
;(setq auto-mode-alist ;; override default .tex mode rule
;      (cons (cons "\\.tex$" 'yatex-mode) auto-mode-alist))

;; po-mode
(autoload 'po-mode "po-mode")
(setq auto-mode-alist
      (cons '("\\.po[tx]?\\'\\|\\.po\\." . po-mode)
	    auto-mode-alist))

;; ChangeLog
(setq user-full-name "PHO")
(setq user-mail-address "pho@cielonegro.org")

(defun memo ()
  (interactive)
  (add-change-log-entry nil (expand-file-name "~/sync/memo.txt")))
(define-key ctl-x-map "M" #'memo)

(defun depression ()
  (interactive)
  (add-change-log-entry nil (expand-file-name "~/sync/depression.txt")))
(define-key ctl-x-map "P" #'depression)

;; Emacs Calc
(add-hook 'calc-start-hook
	  (lambda ()
	    (if (functionp 'paren-deactivate)
		(paren-deactivate))))
(add-hook 'calc-end-hook
	  (lambda ()
	    (if (functionp 'paren-activate)
		(paren-activate))))

;; hooks
(mapcar (lambda (hook)
	  (add-hook hook
		    (lambda ()
		      (local-set-key "\C-m" 'newline-and-indent)
		      (local-set-key "\C-j" 'newline)
		      )))
	'(perl-mode-hook
	  cperl-mode-hook
	  java-mode-hook
	  javascript-mode-hook
	  c-mode-hook
	  c++-mode-hook
	  objc-mode-hook
	  emacs-lisp-mode-hook
	  lisp-mode-hook
	  yatex-mode-hook
	  css-mode-hook
	  scheme-mode-hook))

;; Wanderlast
;(autoload 'wl "wl" "Wanderlust" t)
;(autoload 'wl-other-frame "wl" "Wanderlust on new frame." t)
;(autoload 'wl-draft "wl-draft" "Write draft with Wanderlust." t)

;;; emacs-w3m
(autoload 'w3m "w3m" "Interface for w3m on Emacs." t)
(autoload 'w3m-browse-url "w3m" "Browse url by w3m." t)
(autoload 'w3m-find-file "w3m" "w3m interface function for local file." t)
(autoload 'w3m-search "w3m-search" "Search QUERY using SEARCH-ENGINE." t)
(autoload 'w3m-weather "w3m-weather" "Display weather report." t)
(autoload 'w3m-antenna "w3m-antenna" "Report chenge of WEB sites." t)
(autoload 'w3m-namazu "w3m-namazu" "Search files with Namazu." t)

;; pov-mode
(autoload 'pov-mode "pov-mode" "POV-Ray scene file mode" t)
(setq auto-mode-alist
      (append '(("\\.pov$" . pov-mode)
		("\\.inc$" . pov-mode)
		) auto-mode-alist))

;; End of user configuration ---------------------------------------------------

;; emacs auto edit
(put 'narrow-to-region 'disabled nil)
(custom-set-variables
  ;; custom-set-variables was added by Custom.
  ;; If you edit it by hand, you could mess it up, so be careful.
  ;; Your init file should contain only one such instance.
  ;; If there is more than one, they won't work right.
 '(Info-additional-directory-list (quote ("/sw/share/info" "/usr/local/info" "/usr/local/share/info")))
 '(appt-display-format (quote window))
 '(appt-message-warning-time 20)
 '(canlock-password "a14fa4d2601465d55585c291fa8b3943e189e716")
 '(cleite:auto-refresh-interval nil)
 '(cleite:measure-srpc-call-time t)
 '(ecb-add-path-for-not-matching-files (quote (t)))
 '(ecb-help-info-path "/sw/share/info/ecb.info")
 '(ecb-layout-name "left14")
 '(ecb-options-version "2.32")
 '(ecb-show-sources-in-directories-buffer (quote always))
 '(ecb-source-path (quote (("~/sandbox/_web-app/Rakka" "Rakka") ("~/sandbox/_haskell/Lucu" "Lucu") ("~/sandbox/_web-app/Kirschbaum" "Kirschbaum") ("~/sandbox/_haskell/HsOpenSSL" "HsOpenSSL") ("~/sandbox/_haskell/HsHyperEstraier" "HsHyperEstraier") ("~/sandbox/_haskell/HsSVN" "HsSVN") ("~/sandbox/_game/RoRo" "RoRo") ("~/sandbox/_haskell/HXT" "HXT") ("~/src/ghc-6.8.3" "ghc-6.8.3") ("/Users/admin/sandbox/dotfiles" "dotfiles") ("/su:root@localhost:/usr/pkgsrc" "pkgsrc"))))
 '(ecb-tip-of-the-day nil)
 '(ecb-tree-buffer-style (quote ascii-guides))
 '(ecb-windows-width 0.2)
 '(elscreen-display-tab t)
 '(haskell-program-name "ghci")
 '(ido-enable-flex-matching t)
 '(ido-everywhere t)
 '(ido-ignore-files (quote ("\\`CVS/" "\\`#" "\\`.#" "\\`\\.\\./" "\\`\\./" "\\.ttc")))
 '(ido-work-directory-list-ignore-regexps (quote ("^\\(/mnt/ibm/\\|/Volumes/IBM80GB/\\)")))
 '(indent-tabs-mode nil)
 '(jabber-nickname "PHO")
 '(jabber-resource "emacs")
 '(jabber-server "jabber.jp")
 '(jabber-username "phonohawk")
 '(js2-basic-offset 4)
 '(js2-indent-on-enter-key t)
 '(js2-use-font-lock-faces t)
 '(mew-field-spec (quote (("^Resent-\\(From\\|To\\|Cc\\|Date\\)" t mew-face-header-important mew-face-header-important) ("^Subject:$" t mew-face-header-important mew-face-header-subject) ("^From:$" t mew-face-header-important mew-face-header-from) ("^\\(To\\|Apparently-To\\):$" t mew-face-header-important mew-face-header-to) ("^\\(Cc\\|Dcc\\|Bcc\\):$" t mew-face-header-important mew-face-header-to) ("^Newsgroups:$" t mew-face-header-important mew-face-header-to) ("^Date:$" t mew-face-header-important mew-face-header-date) ("^Reply-To:$" t) ("^X-Mailer:$" t) ("^X-Mew:$" t mew-face-header-important mew-face-header-xmew) ("^\\(Received\\|Return-Path\\|Sender\\|Errors-To\\):$" nil) ("^\\(Path\\|Distribution\\|Xref\\):$" nil) ("^NNTP-Posting-" nil) ("^\\(Message-Id\\|Posted\\|In-Reply-To\\|References\\|Precedence\\):$" nil) ("^Delivered-" nil) ("^List-" nil) ("^\\(Mime-Version\\|Lines\\):$" nil) ("^From$" nil) ("^Status:$" nil) ("^Face:$" nil mew-face-header-private mew-face-header-marginal) ("^X-Text-Classification:$" t mew-face-header-important mew-face-header-important) ("^X-POPFile-Link:$" t mew-face-header-important mew-face-body-url) ("^\\(X\\|Original\\)-" nil mew-face-header-private mew-face-header-marginal))))
 '(mew-refile-guess-alist (quote (("From:" ("noreply@adc1.apple.com" . "+mm/adc") ("mag2 ID 0000022139" . "+mm/2ch") ("noreply@sourceforge.net" . "+from/sf-net")) ("Subject:" ("w3m-dev" . "+ml/w3m-dev")) ("To:" ("glasgow-haskell-users@haskell.org" . "+ml/ghc-users") ("fink-devel@lists.sourceforge.net" . "+ml/fink-devel")) ("Reply-To:" ("yun@kokonoe.com" . "+mm/kokonoe")) ("Cc:" ("glasgow-haskell-users@haskell.org" . "+ml/ghc-users")))))
 '(mew-scan-fields (quote ("Folder:" "Filename:" "Subject:" "Date:" "From:" "To:" "Cc:" "Content-Type:" "Content-Transfer-Encoding:" "X-Mew-Uidl:" "Message-Id:" "In-Reply-To:" "References:" "X-Mew-Ref:" "X-Text-Classification:" "Body")))
 '(mew-spam: "X-Text-Classification:")
 '(mew-summary-form (quote (type (5 date) " " (14 from) " " t (14 x-classification) " " (30 subj) "|" (0 body))))
 '(mouse-wheel-progessive-speed nil)
 '(mouse-wheel-scroll-amount (quote (1 ((shift) . 5) ((control)))))
 '(navi2ch-browse-url-browser-function (quote browse-url-default-macosx-browser))
 '(navi2ch-mona-face-variable (quote navi2ch-mona16-face))
 '(navi2ch-mona-on-message-mode t)
 '(newsticker-html-renderer (quote w3m-region))
 '(newsticker-url-list nil)
 '(newsticker-url-list-defaults (quote (("slashdot" "http://slashdot.org/index.rss" nil 3600))))
 '(nxml-auto-insert-xml-declaration-flag t)
 '(nxml-slash-auto-complete-flag t)
 '(rng-schema-locating-files (quote ("schemas.xml" "/sw/share/schema/schemas.xml" "~/share/nxml/schemas.xml")))
 '(safe-local-variable-values (quote ((todo-categories "Todo" "Todo" "Todo" "Todo"))))
 '(w3m-bookmark-file-coding-system (quote utf-8))
 '(w3m-coding-system (quote utf-8))
 '(w3m-coding-system-priority-list (quote (utf-8)))
 '(w3m-default-coding-system (quote utf-8))
 '(w3m-default-display-inline-images t)
 '(w3m-file-coding-system (quote utf-8))
 '(w3m-file-name-coding-system (quote utf-8))
 '(w3m-fill-column 80)
 '(w3m-input-coding-system (quote utf-8))
 '(w3m-key-binding nil)
 '(w3m-output-coding-system (quote utf-8))
 '(w3m-terminal-coding-system (quote utf-8))
 '(w3m-use-cookies t)
 '(x-select-enable-clipboard t))
(custom-set-faces
  ;; custom-set-faces was added by Custom.
  ;; If you edit it by hand, you could mess it up, so be careful.
  ;; Your init file should contain only one such instance.
  ;; If there is more than one, they won't work right.
 '(flyspell-incorrect ((t (:foreground "OrangeRed" :overline t))))
 '(which-func-face ((t (:background "black" :foreground "dark orange")))))
